==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/network/serversocket.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SERVERSOCKET_H
#define SERVERSOCKET_H

// Qt includes
#include <qserversocket.h>

// forward declarations
class QSocket;

class ServerSocket : public QServerSocket
{
Q_OBJECT

public:
	ServerSocket(int port, QObject* parent=0, const char* name=0);
	~ServerSocket();

	void newConnection(int socketfd);

signals:
	void newClient(QSocket* socket);
};

#endif

// end of file

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/network/serversocket.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SERVERSOCKET_H
#define SERVERSOCKET_H

// Qt includes
#include <qserversocket.h>

// forward declarations
class QSocket;

class ServerSocket : public QServerSocket {
    Q_OBJECT

public:
    ServerSocket(int port, QObject* parent=0, const char* name=0);
    ~ServerSocket();

    void newConnection(int socketfd);

signals:
    void newClient(QSocket* socket);
};

#endif

// end of file
